# -*- coding: utf-8 -*-

import grok

from hurry import yui
from zope.component import getMultiAdapter
from zope.location.interfaces import ISite
from waeup.browser.pages import UniversityPage, FacultyContainerPage
from waeup.interfaces import (IUniversity, IWAeUPObject, IWAeUPXMLExporter,
                              IWAeUPXMLImporter, IFacultyContainer, IFaculty,
                              IDepartment, ICourse, ICertificate,
                              ICertificateCourse,)
from waeup.utils.helpers import getInnerHTMLPart
from waeup.viewlets import LeftSidebar, ActionBar

grok.templatedir('templates')

#grok.context(zope.interface.Interface)

#
# waeup.app.University viewlets...
#
class Login(grok.Viewlet):
    """This viewlet allows to login in the sidebar.
    """
    grok.viewletmanager(LeftSidebar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.order(2)

    def isAuthenticated(self):
        """Is the calling user authenticated?
        """
        return self.request.principal.id != 'zope.anybody'

class ManageLink(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.order(5)
    # This link is only displayed, if the user is
    # allowed to use it!
    grok.require('waeup.manageUniversity')
    
    def render(self):
        return u'<div class="portlet"><a href="manage">Settings</a></div>'

class ManageFacultiesLink(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.order(6)
    # This is so cool! This link is only displayed, when the user is
    # allowed to use it!
    grok.require('waeup.manageUniversity')
    
    def render(self):
        return u'<div class="portlet"><a href="faculties">Manage faculties</a></div>'

class ManageUsersLink(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.order(6)
    grok.require('waeup.manageUsers')

    def render(self):
        return u'<div class="portlet"><a href="users">Manage users</a></div>'

class ManageDataCenter(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.order(6)
    grok.require('waeup.manageUniversity')

    def render(self):
        return u'<div class="portlet"><a href="datacenter">Data Center</a></div>'

class ManageUniversityAction(grok.Viewlet):
    grok.viewletmanager(ActionBar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.require('waeup.manageUniversity')
    grok.order(2)
    grok.template('manageaction')

class GoToFacultiesAction(grok.Viewlet):
    grok.viewletmanager(ActionBar)
    grok.context(IUniversity)
    grok.view(UniversityPage)
    grok.require('waeup.manageUniversity')
    grok.order(3)
    grok.template('gotofacultiesaction')

class ManageFacultiesAction(ManageUniversityAction):
    grok.context(IFacultyContainer)
    grok.view(FacultyContainerPage)
    grok.template('manageaction')


#
# Add actions...
#
class AddAction(grok.Viewlet):
    """Base class for 'adding actions'.

    AddActions are viewlets that render a button linked to an adding
    page. To create such a button in one of your pages, follow the
    following steps:

    - Create a new class derived from AddAction. In this class:
    
    - Set a grok.context() for the context type of your page. So, if
      your page sets grok.context(IMyFunnyType), do the same in the
      viewlet class.

    - Set the Page on which the button should appear using
      grok.view(). So, if your page class is MyFunnyPage, do
      grok.view(MyFunnyPage).

    - Set the template to use to 'addaction'. This means to use the
      'addaction.pt' template in the templates/ dir. Don't fiddle
      around with this template file, as it is used also by other
      viewlets.

    - If you want only certain authorized users to see the button, use
      grok.require(<Permission>). By default only people with
      waeup.manageUniversity permission are able to see your new
      button. Other users, however, will still see your page, only
      without the button rendered.

    - As one can define several buttons for a certain page, you can
      influence the order of buttons by setting grok.order(<num>). The
      lower the number, the more left the button will be displayed and
      vice versa. Default is 4.
      
    - Set the page name as ``addview_name`` attribute. This means, if
      the page, the button is linked to can be reached by calling
      http://localhost:8080/<current_location>/@@addfoo, then you should set::

        addview_name = 'addfoo'

      By default the target page name 'add' is assumed. You should
      have good reasons not to name your AddFormPage 'add'.

    - Set the button text by setting the ``addlink_text``
      attribute. If you set it to 'Add foobar', then on the page will
      appear a button with a small 'add stuff' icon and the text 'Add
      foobar'.
    """
    grok.viewletmanager(ActionBar)
    grok.view(FacultyContainerPage)
    grok.context(IFacultyContainer)
    grok.order(4)
    grok.template('addaction')
    grok.require('waeup.manageUniversity')
    grok.baseclass()

    addview_name = 'add'
    addlink_text = 'Add department'

    def getTargetURL(self):
        return '%s/@@%s' % (self.view.url(self.view.context), self.addview_name)

class AddFacultiesAction(AddAction):
    grok.context(IFacultyContainer)
    grok.view(FacultyContainerPage)
    grok.order(4)
    grok.template('addaction')
    grok.require('waeup.manageUniversity')

    addview_name = 'add'
    addlink_text = 'Add faculty'

